# -*- coding: utf-8 -*

from django.conf import settings
from django.core.cache import get_cache
from django.utils.importlib import import_module


class UserRestrictMiddleware(object):
    """
    Middleware to prevent users to log in multiple times with the same credentials
    http://mirobetm.blogspot.it/2013/02/restricting-django-to-one-user.html
    """

    def process_request(self, request):
        """
        Checks if different session exists for user and deletes it.
        """
        if request.user.is_authenticated():
            cache = get_cache('default')
            cache_timeout = 86400
            cache_key = "user_pk_{}_restrict".format(request.user.pk)
            cache_value = cache.get(cache_key)

            if cache_value is not None:
                if request.session.session_key != cache_value:
                    engine = import_module(settings.SESSION_ENGINE)
                    session = engine.SessionStore(session_key=cache_value)
                    session.delete()
                    cache.set(cache_key, request.session.session_key, cache_timeout)
            else:
                cache.set(cache_key, request.session.session_key, cache_timeout)
